@@ -1,5 +1,6 @@
 from typing import List, Optional
 
+import numpy as np
 import pandas as pd
 
 from exodusutils.exceptions.exceptions import ExodusMethodNotAllowed
@@ -25,7 +26,13 @@ columns found in `fit` from the given dataframe. Will not remove the target colu
         self.constant_columns = [
             column.name
             for column in self.feature_types
-            if column.name != self.target_column_name and df[column.name].nunique() == 1
+            if column.name != self.target_column_name
+            and (
+                (df[column.name].isnull().all())  # All NaNs
+                or (
+                    df[column.name].notnull().all() and df[column.name].nunique() == 1
+                )  # Only one kind of value without any NaN
+            )
         ]
 
     def transform(self, df: pd.DataFrame) -> pd.DataFrame:
