@@ -191,6 +191,16 @@ class PredictReqBody(BaseModel):
         default=[], description="The columns to keep in the prediction response"
     )
 
+    def get_keep_columns_df(self) -> pd.DataFrame:
+        """
+        Returns a Pandas DataFrame with only the columns specified in the `keep_columns` parameter
+        """
+        df = pd.DataFrame(pd.read_json(self.data, orient="records"))
+        return df.drop(
+            [c for c in df.columns.tolist() if c not in self.keep_columns], axis=1
+        )
+
+
     def get_prediction_df(self, feature_types: List[Column]) -> pd.DataFrame:
         """
         Returns the Pandas DataFrame from the bytes in data field.
