@@ -209,7 +209,7 @@ class ClassificationScores(BaseModel):
             def mean(arr):
                 return sum(arr) / float(len(arr))
 
-            top_group = sorted(zip(pred, actual), key=lambda x: x[0])
+            top_group = sorted(zip(pred, actual), key=lambda x: -x[0])
             one_percent_len = int(math.ceil(len(top_group) / 100.0))
             return mean([x[1] for x in top_group[:one_percent_len]]) / float(
                 mean(actual)
@@ -220,7 +220,7 @@ class ClassificationScores(BaseModel):
         actual = le.transform(actual)
         pred = le.transform(pred)
         log_loss_ = log_loss(actual, pred_proba, labels=labels)
-        pred_scores = [pred_proba[i[0]][x] for i, x in np.ndenumerate(pred)]
+        # pred_scores = [pred_proba[i[0]][x] for i, x in np.ndenumerate(pred)]
         misclassification = 1 - accuracy_score(actual, pred)
         mpce = mean_per_class_error(list(pred), list(actual))
         if len(labels) > 2:  # n-ary classification problem
@@ -230,6 +230,7 @@ class ClassificationScores(BaseModel):
                 misclassification=misclassification,
             )
         else:
+            pred_scores = [pred_proba[i][1] for i in range(len(pred_proba))]
             fpr, tpr, _ = roc_curve(actual, pred_scores, pos_label=None)
             auc_ = auc(fpr, tpr)
             lift = lift_top_group(pred_scores, list(actual))
